@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Richard Dymond (rjdymond@gmail.com)
+# Copyright 2012-2014 Richard Dymond (rjdymond@gmail.com)
 #
 # This file is part of SkoolKit.
 #
@@ -71,8 +71,6 @@ GIF_ENABLE_ANIMATION = 'GIFEnableAnimation'
 #: Option name that specifies whether to create transparent GIFs for masked
 #: images.
 GIF_TRANSPARENCY = 'GIFTransparency'
-#: Option name that specifies whether GIFs should be compressed.
-GIF_COMPRESSION = 'GIFCompression'
 
 PNG_FORMAT = 'png'
 GIF_FORMAT = 'gif'
@@ -106,23 +104,28 @@ class ImageWriter:
             PNG_FORMAT: self.options[PNG_ENABLE_ANIMATION],
             GIF_FORMAT: self.options[GIF_ENABLE_ANIMATION]
         }
+        self.masks = {
+            0: NoMask(),
+            1: OrAndMask(),
+            2: AndOrMask()
+        }
         self.writers = {
-            PNG_FORMAT: PngWriter(self.options[PNG_ALPHA] & 255, self.options[PNG_COMPRESSION_LEVEL]),
-            GIF_FORMAT: GifWriter(self.options[GIF_TRANSPARENCY], self.options[GIF_COMPRESSION])
+            PNG_FORMAT: PngWriter(self.options[PNG_ALPHA] & 255, self.options[PNG_COMPRESSION_LEVEL], self.masks),
+            GIF_FORMAT: GifWriter(self.options[GIF_TRANSPARENCY], self.masks)
         }
 
     def write_image(self, frames, img_file, img_format):
         use_flash = len(frames) == 1 and self.animation.get(img_format)
         attrs = set()
         colours = set()
-        trans = 0
+        has_trans = False
         for frame in frames:
             f_colours, f_attrs, flash_rect = self._get_colours(frame, use_flash)
             colours.update(f_colours)
             attrs.update(f_attrs)
-            trans = trans or frame.trans
-        palette, attr_map = self._get_palette(colours, attrs, trans)
-        self.writers[img_format].write_image(frames, img_file, palette, attr_map, trans, flash_rect)
+            has_trans = has_trans or frame.has_trans
+        palette, attr_map = self._get_palette(colours, attrs, has_trans)
+        self.writers[img_format].write_image(frames, img_file, palette, attr_map, has_trans, flash_rect)
 
     def _get_default_palette(self):
         return  {
@@ -151,8 +154,7 @@ class ImageWriter:
             PNG_ENABLE_ANIMATION: 1,
             PNG_ALPHA: 255,
             GIF_ENABLE_ANIMATION: 1,
-            GIF_TRANSPARENCY: 0,
-            GIF_COMPRESSION: 1
+            GIF_TRANSPARENCY: 0
         }
 
     def _create_colours(self, palette):
@@ -195,104 +197,104 @@ class ImageWriter:
             return self._get_all_colours(frame, use_flash)
 
         udg_array = frame.udgs
+        null_mask = frame.mask == 0
         scale = frame.scale
-        mask = frame.mask
-        x, y, width, height = frame.x, frame.y, frame.width, frame.height
+        mask = self.masks[frame.mask]
+        x0, y0, width, height = frame.x, frame.y, frame.width, frame.height
+        x1 = x0 + width
+        y1 = y0 + height
         attrs = set()
         colours = set()
-        has_trans = 0
+        has_masks = 0
         all_masked = 1
         flashing = False
-        y_count = 0
         inc = 8 * scale
+        min_col = x0 // inc
+        max_col = x1 // inc
+        min_row = y0 // inc
+        max_row = y1 // inc
+        x0_floor = inc * min_col
+        y0_floor = inc * min_row
+        x1_floor = inc * max_col
+        y1_floor = inc * max_row
         min_x = width
         min_y = height
         max_x = max_y = 0
-        rows = 0
-        for row in udg_array:
-            if y_count >= y + height:
-                break
-            if y_count + inc - 1 < y:
-                y_count += inc
-                continue
-            for j in range(8):
-                if y_count + scale - 1 < y:
-                    y_count += scale
-                    continue
-                if y_count >= y:
-                    num_lines = min(y + height - y_count, scale)
+
+        y = y0_floor
+        for row in udg_array[min_row:max_row + 1]:
+            x = x0_floor
+            for udg in row[min_col:max_col + 1]:
+                attr = udg.attr & 127
+                attrs.add(attr)
+                paper, ink = self.attr_index[attr]
+                udg_flashing = False
+                if use_flash and udg.attr & 128:
+                    colours.add(ink)
+                    if ink != paper:
+                        colours.add(paper)
+                        flashing = True
+                        udg_flashing = True
+                if udg.mask:
+                    has_masks = 1
                 else:
-                    num_lines = y_count - y + scale
-                x_count = 0
-                cols = 0
-                for udg in row:
-                    if x_count >= x + width:
-                        break
-                    if x_count + inc - 1 < x:
-                        x_count += inc
-                        continue
-                    attr = udg.attr & 127
-                    attrs.add(attr)
-                    paper, ink = self.attr_index[attr]
-                    byte = udg.data[j]
-                    if mask and udg.mask:
-                        mask_byte = udg.mask[j]
-                        byte &= mask_byte
-                    else:
-                        all_masked = 0
-                        mask_byte = 0
-                    if use_flash and udg.attr & 128:
-                        colours.add(ink)
-                        if ink != paper:
-                            colours.add(paper)
-                            flashing = True
-                    for k in range(8):
-                        if x_count >= x + width:
+                    all_masked = 0
+                if x0 <= x < x1_floor and y0 <= y < y1_floor:
+                    # Uncropped UDG
+                    for j in range(8):
+                        if ink in colours and paper in colours and (null_mask or None in colours):
                             break
-                        if x_count + scale - 1 < x:
-                            x_count += scale
-                            byte *= 2
-                            mask_byte *= 2
-                            continue
-                        if x_count >= x:
-                            num_bits = min(x + width - x_count, scale)
-                        else:
-                            num_bits = x_count - x + scale
-                        if use_flash and udg.attr & 128 and ink != paper:
-                            min_x = min((cols, min_x))
-                            max_x = max((cols + num_bits, max_x))
-                            min_y = min((rows, min_y))
-                            max_y = max((rows + num_lines, max_y))
-                        if byte & 128:
-                            colours.add(ink)
-                        elif mask_byte & 128:
-                            has_trans = 1
-                        else:
-                            colours.add(paper)
-                        byte *= 2
-                        mask_byte *= 2
-                        x_count += scale
-                        cols += num_bits
-                y_count += scale
-                rows += num_lines
+                        colours.update(mask.apply(udg, j, paper, ink, None))
+                    if udg_flashing:
+                        min_x = min(x, min_x)
+                        max_x = max(x + inc, max_x)
+                        min_y = min(y, min_y)
+                        max_y = max(y + inc, max_y)
+                else:
+                    # Cropped UDG
+                    min_k = max(0, (x0 - x) // scale)
+                    max_k = min(8, 1 + (x1 - 1 - x) // scale)
+                    min_j = max(0, (y0 - y) // scale)
+                    max_j = min(8, 1 + (y1 - 1 - y) // scale)
+                    for j in range(min_j, max_j):
+                        if ink in colours and paper in colours and (null_mask or None in colours):
+                            break
+                        for pixel in mask.apply(udg, j, paper, ink, None)[min_k:max_k]:
+                            colours.add(pixel)
+                    if udg_flashing:
+                        fx0 = max(x0, x + min_k * scale)
+                        fx1 = min(x1, x + max_k * scale)
+                        fy0 = max(y0, y + min_j * scale)
+                        fy1 = min(y1, y + max_j * scale)
+                        min_x = min(fx0, min_x)
+                        max_x = max(fx1, max_x)
+                        min_y = min(fy0, min_y)
+                        max_y = max(fy1, max_y)
+                x += inc
+            y += inc
 
         if flashing:
-            flash_rect = (min_x, min_y, max_x - min_x, max_y - min_y)
+            flash_rect = (min_x - x0, min_y - y0, max_x - min_x, max_y - min_y)
         else:
             flash_rect = None
-        if has_trans:
-            frame.trans = 1 + all_masked
+        if None in colours:
+            colours.remove(None)
+            frame.has_trans = True
         else:
-            frame.trans = 0
+            frame.has_trans = False
+        frame.has_masks = has_masks
+        frame.all_masked = all_masked
         return colours, attrs, flash_rect
 
     def _get_all_colours(self, frame, use_flash=False):
         # Find all the colours in an uncropped image
         udg_array = frame.udgs
-        mask = frame.mask
+        null_mask = frame.mask == 0
+        mask = self.masks[frame.mask]
         attrs = set()
         colours = set()
-        has_trans = 0
+        has_trans = False
+        has_masks = 0
         all_masked = 1
         flashing = False
         min_x = len(udg_array[0])
@@ -306,41 +308,28 @@ class ImageWriter:
                 attr = udg.attr
                 attrs.add(attr & 127)
                 paper, ink = self.attr_index[attr & 127]
-                if mask and udg.mask:
-                    data = [udg.data[i] & udg.mask[i] for i in range(8)]
-                    has_non_trans = False
-                    if any(data):
+                has_non_trans = False
+                for i in range(8):
+                    pixels = mask.apply(udg, i, paper, ink, None)
+                    if ink in pixels:
                         colours.add(ink)
                         has_non_trans = True
-                    if any([b < 255 for b in udg.mask]):
+                    if paper in pixels:
                         colours.add(paper)
                         has_non_trans = True
-                    if use_flash and attr & 128 and has_non_trans:
-                        colours.add(ink)
-                        if ink != paper:
-                            min_x = min((x, min_x))
-                            min_y = min((y, min_y))
-                            max_x = max((x, max_x))
-                            max_y = max((y, max_y))
-                            colours.add(paper)
-                            flashing = True
-                    if any([data[i] | udg.mask[i] > data[i] for i in range(8)]):
-                        has_trans = 1
-                elif use_flash and attr & 128:
-                    colours.add(ink)
-                    if ink != paper:
-                        min_x = min((x, min_x))
-                        min_y = min((y, min_y))
-                        max_x = max((x, max_x))
-                        max_y = max((y, max_y))
-                        colours.add(paper)
-                        flashing = True
-                    all_masked = 0
+                    if None in pixels:
+                        has_trans = True
+                    if ink in colours and paper in colours and (null_mask or has_trans):
+                        break
+                if use_flash and attr & 128 and ink != paper and has_non_trans:
+                    min_x = min(x, min_x)
+                    min_y = min(y, min_y)
+                    max_x = max(x, max_x)
+                    max_y = max(y, max_y)
+                    flashing = True
+                if udg.mask:
+                    has_masks = 1
                 else:
-                    if any(udg.data):
-                        colours.add(ink)
-                    if any([b < 255 for b in udg.data]):
-                        colours.add(paper)
                     all_masked = 0
                 x += 1
             y += 1
@@ -349,17 +338,16 @@ class ImageWriter:
             flash_rect = (min_x, min_y, max_x - min_x + 1, max_y - min_y + 1)
         else:
             flash_rect = None
-        if has_trans:
-            frame.trans = 1 + all_masked
-        else:
-            frame.trans = 0
+        frame.has_trans = has_trans
+        frame.has_masks = has_masks
+        frame.all_masked = all_masked
         return colours, attrs, flash_rect
 
-    def _get_palette(self, colours, attrs, trans):
+    def _get_palette(self, colours, attrs, has_trans):
         colour_map = {}
         palette = []
         i = 0
-        if trans:
+        if has_trans:
             palette.extend(self.colours[0])
             i += 1
         for colour in colours:
@@ -373,3 +361,70 @@ class ImageWriter:
             attr_map[attr] = (colour_map.get(paper, 0), colour_map.get(ink, 0))
 
         return palette, attr_map
+
+class NoMask:
+    def apply(self, udg, row, paper, ink, trans):
+        udg_byte = udg.data[row]
+        pixels = []
+        for b in range(8):
+            if udg_byte & 128:
+                pixels.append(ink)
+            else:
+                pixels.append(paper)
+            udg_byte *= 2
+        return pixels
+
+class OrAndMask:
+    def apply(self, udg, row, paper, ink, trans):
+        udg_byte = udg.data[row]
+        if udg.mask:
+            mask_byte = udg.mask[row]
+        else:
+            mask_byte = udg_byte
+        pixels = [paper] * 8
+        index = 7
+        while mask_byte:
+            if mask_byte & 1:
+                if udg_byte & 1:
+                    pixels[index] = ink
+                else:
+                    pixels[index] = trans
+            udg_byte //= 2
+            mask_byte //= 2
+            index -= 1
+        return pixels
+
+    def colours(self, patterns, paper, ink, trans):
+        return (
+            patterns[paper], # 00
+            patterns[trans], # 01
+            patterns[paper], # 10
+            patterns[ink]    # 11
+        )
+
+class AndOrMask:
+    def apply(self, udg, row, paper, ink, trans):
+        udg_byte = udg.data[row]
+        if udg.mask:
+            mask_byte = udg.mask[row]
+        else:
+            mask_byte = udg_byte
+        pixels = [paper] * 8
+        index = 7
+        while udg_byte or mask_byte:
+            if udg_byte & 1:
+                pixels[index] = ink
+            elif mask_byte & 1:
+                pixels[index] = trans
+            udg_byte //= 2
+            mask_byte //= 2
+            index -= 1
+        return pixels
+
+    def colours(self, patterns, paper, ink, trans):
+        return (
+            patterns[paper], # 00
+            patterns[trans], # 01
+            patterns[ink],   # 10
+            patterns[ink]    # 11
+        )
