@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2009-2013 Richard Dymond (rjdymond@gmail.com)
+# Copyright 2009-2014 Richard Dymond (rjdymond@gmail.com)
 #
 # This file is part of SkoolKit.
 #
@@ -26,7 +26,7 @@ class RefParser:
 
     def _add_section(self, section_name, section_lines):
         if section_name:
-            while not section_lines[-1]:
+            while section_lines and not section_lines[-1]:
                 section_lines.pop()
             self.ref.append((section_name, section_lines))
             self.sections[section_name] = section_lines
@@ -39,14 +39,18 @@ class RefParser:
         """
         section_name = None
         section_lines = []
-        with open_file(reffile) as infile:
-            for line in infile:
-                if line.startswith('['):
-                    self._add_section(section_name, section_lines)
-                    section_name = line[1:line.index(']')]
-                    section_lines = []
-                elif not line.startswith(';'):
-                    section_lines.append(line.rstrip())
+        infile = open_file(reffile)
+        for line in infile:
+            s_line = line.rstrip()
+            if s_line.startswith(('[[', ';;')):
+                section_lines.append(s_line[1:])
+            elif s_line.startswith('[') and s_line.endswith(']'):
+                self._add_section(section_name, section_lines)
+                section_name = s_line[1:-1]
+                section_lines = []
+            elif not s_line.startswith(';'):
+                section_lines.append(s_line)
+        infile.close()
         self._add_section(section_name, section_lines)
  
     def add_line(self, section_name, line):
@@ -145,7 +149,10 @@ class RefParser:
         dictionary = {}
         for line in contents:
             if line:
-                key, value = line.split('=', 1)
+                try:
+                    key, value = line.split('=', 1)
+                except ValueError:
+                    continue
                 if key.isdigit():
                     key = int(key)
                 dictionary[key] = value
