@@ -22,12 +22,16 @@ from os.path import isfile, isdir, basename, dirname
 import shutil
 import time
 import argparse
+try:
+    from StringIO import StringIO
+except ImportError:         # pragma: no cover
+    from io import StringIO # pragma: no cover
 
 from . import PACKAGE_DIR, VERSION, show_package_dir, write, write_line, get_class, normpath, SkoolKitError
-from .image import ImageWriter
 from .skoolhtml import FileInfo
 from .skoolparser import SkoolParser, CASE_UPPER, CASE_LOWER, BASE_10, BASE_16
 from .refparser import RefParser
+from . import defaults
 
 verbose = True
 show_timings = False
@@ -61,6 +65,14 @@ def show_search_dirs():
         write_line(prefix + search_dir)
     sys.exit(0)
 
+def show_ref_file():
+    write(defaults.REF_FILE)
+    sys.exit(0)
+
+def show_ref_sections(prefix):
+    write(defaults.get_sections(prefix))
+    sys.exit(0)
+
 def notify(notice):
     if verbose:
         write_line(notice)
@@ -95,27 +107,6 @@ def add_lines(ref_parser, config_specs, section=None):
         if section is None or section_name == section:
             ref_parser.add_line(section_name, line)
 
-def get_colours(colour_specs):
-    colours = {}
-    for k, v in colour_specs.items():
-        if v.startswith('#'):
-            hex_rgb = v[1:7]
-            if len(hex_rgb) == 3:
-                hex_rgb = '{0}{0}{1}{1}{2}{2}'.format(*hex_rgb)
-            else:
-                hex_rgb = '0' * (6 - len(hex_rgb)) + hex_rgb
-            values = [hex_rgb[i:i + 2] for i in range(0, 5, 2)]
-            base = 16
-        else:
-            values = v.split(',')[:3]
-            values.extend(['0'] * (3 - len(values)))
-            base = 10
-        try:
-            colours[k] = tuple([int(n, base) for n in values])
-        except ValueError:
-            raise SkoolKitError("Invalid colour spec: {}={}".format(k, v))
-    return colours
-
 def copy_resource(fname, root_dir, dest_dir, indent=0):
     base_f = basename(fname)
     dest_f = normpath(root_dir, dest_dir, base_f)
@@ -199,11 +190,13 @@ def process_file(infile, topdir, files, case, base, pages, config_specs, new_ima
     if reffile_f:
         reffiles.insert(0, normpath(reffile_f))
     ref_parser = RefParser()
+    ref_parser.parse(StringIO(defaults.get_section('Config')))
+    config = ref_parser.get_dictionary('Config')
     for oreffile_f in reffiles:
         ref_parser.parse(oreffile_f)
     add_lines(ref_parser, config_specs)
+    config.update(ref_parser.get_dictionary('Config'))
 
-    config = ref_parser.get_dictionary('Config')
     if skoolfile_f is None:
         skoolfile = config.get('SkoolFile', '{}.skool'.format(prefix))
         skoolfile_f = find(skoolfile, ref_search_dir)
@@ -221,7 +214,7 @@ def process_file(infile, topdir, files, case, base, pages, config_specs, new_ima
     else:
         notify('Found no ref file for {}'.format(skoolfile_n))
 
-    html_writer_class = get_class(config.get('HtmlWriterClass', 'skoolkit.skoolhtml.HtmlWriter'))
+    html_writer_class = get_class(config['HtmlWriterClass'])
     game_dir = config.get('GameDir', prefix)
 
     # Parse the skool file and initialise the writer
@@ -231,10 +224,7 @@ def process_file(infile, topdir, files, case, base, pages, config_specs, new_ima
         fname = skoolfile_f
     skool_parser = clock(SkoolParser, 'Parsing {0}'.format(fname), skoolfile_f, case=case, base=base, html=True, create_labels=create_labels, asm_labels=asm_labels)
     file_info = FileInfo(topdir, game_dir, new_images)
-    colours = get_colours(ref_parser.get_dictionary('Colours'))
-    iw_options = ref_parser.get_dictionary('ImageWriter')
-    image_writer = ImageWriter(colours, iw_options)
-    html_writer = html_writer_class(skool_parser, ref_parser, file_info, image_writer, case)
+    html_writer = html_writer_class(skool_parser, ref_parser, file_info, case)
 
     # Check that the specified pages exist
     all_page_ids = html_writer.get_page_ids()
@@ -276,11 +266,8 @@ def write_disassembly(html_writer, files, search_dir, pages, css_theme, single_c
 
     # Write the memory map files
     if 'm' in files:
-        for map_name in html_writer.memory_map_names:
-            map_details = html_writer.memory_maps[map_name]
-            if html_writer.should_write_map(map_details):
-                map_path = html_writer.get_map_path(map_details)
-                clock(html_writer.write_map, '  Writing {}'.format(normpath(game_dir, map_path)), map_details)
+        for map_name in html_writer.main_memory_maps:
+            clock(html_writer.write_map, '  Writing {}'.format(normpath(game_dir, paths[map_name])), map_name)
 
     # Write pages defined in the ref file
     if 'P' in files:
@@ -290,10 +277,6 @@ def write_disassembly(html_writer, files, search_dir, pages, css_theme, single_c
             clock(html_writer.write_page, '  Writing {}'.format(normpath(game_dir, paths[page_id])), page_id)
 
     # Write other files
-    if 'G' in files and html_writer.has_gbuffer():
-        clock(html_writer.write_gbuffer, '  Writing {}'.format(normpath(game_dir, paths['GameStatusBuffer'])))
-    if 'g' in files and html_writer.graphics:
-        clock(html_writer.write_graphics, '  Writing {}'.format(normpath(game_dir, paths['Graphics'])))
     if 'B' in files and html_writer.graphic_glitches:
         clock(html_writer.write_graphic_glitches, '  Writing {}'.format(normpath(game_dir, paths['GraphicGlitches'])))
     if 'c' in files and html_writer.changelog:
@@ -312,15 +295,11 @@ def write_disassembly(html_writer, files, search_dir, pages, css_theme, single_c
             skoolfile = find(code['Source'], search_dir)
             skool2_parser = clock(html_writer.parser.clone, '  Parsing {0}'.format(skoolfile), skoolfile)
             html_writer2 = html_writer.clone(skool2_parser, code_id)
-            map_path = code['Index']
-            asm_path = code['Path']
-            map_details = {
-                'Path': map_path,
-                'AsmPath': asm_path,
-                'Title': code['Title']
-            }
-            clock(html_writer2.write_map, '    Writing {}'.format(normpath(game_dir, map_path)), map_details)
-            clock(html_writer2.write_entries, '    Writing disassembly files in {}'.format(normpath(game_dir, asm_path)), asm_path, map_path, code['Header'])
+            map_name = code['IndexPageId']
+            map_path = paths[map_name]
+            asm_path = paths[code['CodePathId']]
+            clock(html_writer2.write_map, '    Writing {}'.format(normpath(game_dir, map_path)), map_name)
+            clock(html_writer2.write_entries, '    Writing disassembly files in {}'.format(normpath(game_dir, asm_path)), asm_path, map_path)
 
     # Write index.html
     if 'i' in files:
@@ -379,6 +358,11 @@ def main(args):
                             "file(s)")
     group.add_argument('-q', '--quiet', dest='verbose', action='store_false',
                        help="Be quiet")
+    group.add_argument('-r', '--ref-sections', dest='ref_sections', metavar='PREFIX',
+                       help="Show default ref file sections whose names start with\n"
+                            "PREFIX and exit")
+    group.add_argument('-R', '--ref-file', dest='ref_file', action='store_true',
+                       help="Show the entire default ref file and exit")
     group.add_argument('-s', '--search-dirs', dest='search_dirs', action='store_true',
                        help="Show the locations skool2html.py searches for resources")
     group.add_argument('-t', '--time', dest='show_timings', action='store_true',
@@ -392,13 +376,12 @@ def main(args):
                        help='Show SkoolKit version number and exit')
     group.add_argument('-w', '--write', dest='files', metavar='X', default='BbcdGgimoPpty',
                        help="Write only these files, where X is one or more of:\n"
-                            "  B = Graphic glitches    m = Memory maps\n"
-                            "  b = Bugs                o = Other code\n"
-                            "  c = Changelog           P = Custom pages\n"
-                            "  d = Disassembly files   p = Pokes\n"
-                            "  G = Game status buffer  t = Trivia\n"
-                            "  g = Graphics            y = Glossary\n"
-                            "  i = Disassembly index")
+                            "  B = Graphic glitches    o = Other code\n"
+                            "  b = Bugs                P = Custom pages\n"
+                            "  c = Changelog           p = Pokes\n"
+                            "  d = Disassembly files   t = Trivia\n"
+                            "  i = Disassembly index   y = Glossary\n"
+                            "  m = Memory maps\n")
 
     start = time.time()
     namespace, unknown_args = parser.parse_known_args(args)
@@ -406,6 +389,10 @@ def main(args):
         show_package_dir()
     if namespace.search_dirs:
         show_search_dirs()
+    if namespace.ref_file:
+        show_ref_file()
+    if namespace.ref_sections is not None:
+        show_ref_sections(namespace.ref_sections)
     if unknown_args or not namespace.infiles:
         parser.exit(2, parser.format_help())
     verbose, show_timings = namespace.verbose, namespace.show_timings
