@@ -46,9 +46,6 @@ class TestHtmlWriter(HtmlWriter):
     def write_page(self, *args):
         self.add_call('write_page', args)
 
-    def write_gbuffer(self, *args):
-        self.add_call('write_gbuffer', args)
-
     def write_graphics(self, *args):
         self.add_call('write_graphics', args)
 
@@ -92,7 +89,7 @@ class MockSkoolParser:
         self.create_labels = kwargs.get('create_labels')
         self.asm_labels = kwargs.get('asm_labels')
         self.snapshot = None
-        self.entries = None
+        self.entries = {}
         self.memory_map = []
         mock_skool_parser = self
 
@@ -111,10 +108,6 @@ class Skool2HtmlTest(SkoolKitTestCase):
         ref = TEST_WRITER_REF + '\n'.join((
             '[OtherCode:other]',
             'Source={0}',
-            'Path=other',
-            'Index=other.html',
-            'Title=Other code',
-            'Header=Other code',
             '[Bug:test:Test]',
             '<p>Hello</p>',
             '[Changelog:20120704]',
@@ -122,16 +115,10 @@ class Skool2HtmlTest(SkoolKitTestCase):
             'Item 1',
             '[Glossary:Term1]',
             'Definition 1.',
-            '[Graphics]',
-            '<em>This is the graphics page.</em>',
             '[Page:CustomPage1]',
-            'Title=Custom page',
-            'Path=page.html',
             '[PageContent:CustomPage1]',
             '<b>This is the content of custom page 1.</b>',
             '[Page:CustomPage2]',
-            'Path=page2.html',
-            'Link=Custom page 2',
             '[PageContent:CustomPage2]',
             'Lo',
             '[GraphicGlitch:SpriteBug]',
@@ -254,7 +241,6 @@ class Skool2HtmlTest(SkoolKitTestCase):
         skoolfile = self.write_text_file(suffix='.skool')
         ref = '\n'.join((
             '[Page:P1]',
-            'Path=p1.html',
             'JavaScript={}'.format(jsfile)
         ))
         self.write_text_file(ref, '{}.ref'.format(skoolfile[:-6]))
@@ -381,7 +367,7 @@ class Skool2HtmlTest(SkoolKitTestCase):
         output, error = self.run_skool2html(skoolfile)
         self.assertEqual(error, '')
         html_writer = write_disassembly_args[0]
-        self.assertEqual(html_writer.game, game)
+        self.assertEqual(html_writer.game['Game'], game)
 
         # Test that a skool file in the same directory as the ref file is found
         output, error = self.run_skool2html(reffile)
@@ -390,44 +376,10 @@ class Skool2HtmlTest(SkoolKitTestCase):
         self.assertEqual(len(html_writer.entries), 1)
         self.assertTrue(30000 in html_writer.entries)
 
-    def test_colour_parsing(self):
-        self.mock(skool2html, 'write_disassembly', mock_write_disassembly)
-        self.mock(skool2html, 'ImageWriter', MockImageWriter)
-
-        # Valid colours
-        exp_colours = (
-            ('RED', '#C40000', (196, 0, 0)),
-            ('WHITE', '#cde', (204, 221, 238)),
-            ('YELLOW', '198,197,0', (198, 197, 0))
-        )
-        colours = ['[Colours]']
-        colours.extend(['{}={}'.format(name, spec) for name, spec, rgb in exp_colours])
-        reffile = self.write_text_file('\n'.join(colours), suffix='.ref')
-        self.write_text_file(path='{0}.skool'.format(reffile[:-4]))
-        output, error = self.run_skool2html(reffile)
-        self.assertEqual(error, '')
-        for name, spec, rgb in exp_colours:
-            self.assertEqual(mock_image_writer.palette[name], rgb)
-
-        # Invalid colours
-        bad_colours = (
-            ('BLACK', ''),
-            ('CYAN', '#)0C6C5'),
-            ('MAGENTA', '!98,0,198')
-        )
-        for name, spec in bad_colours:
-            colours = ['[Colours]', '{}={}'.format(name, spec)]
-            reffile = self.write_text_file('\n'.join(colours), suffix='.ref')
-            self.write_text_file(path='{0}.skool'.format(reffile[:-4]))
-            with self.assertRaises(SkoolKitError) as cm:
-                self.run_skool2html(reffile)
-            self.assertEqual(cm.exception.args[0], 'Invalid colour spec: {}={}'.format(name, spec))
-
     def test_image_writer_options(self):
         self.mock(skool2html, 'write_disassembly', mock_write_disassembly)
         exp_iw_options = (
             ('DefaultFormat', 'gif'),
-            ('GIFCompression', 0),
             ('GIFEnableAnimation', 0),
             ('GIFTransparency', 1),
             ('PNGAlpha', 1),
@@ -487,7 +439,6 @@ class Skool2HtmlTest(SkoolKitTestCase):
             'JavaScript={}',
             '[Page:CustomPage]',
             'JavaScript={}',
-            'Path=page.html',
             'PageContent=<b>Hello</b>'
         )).format(global_js_file, local_js_file)
         reffile = self.write_text_file(ref, suffix='.ref')
@@ -506,7 +457,6 @@ class Skool2HtmlTest(SkoolKitTestCase):
             'JavaScript={}',
             '[Page:CustomPage]',
             'JavaScript={}',
-            'Path=page.html',
             'PageContent=<b>Hello</b>'
         )).format(';'.join(global_js_files), ';'.join(local_js_files))
         reffile = self.write_text_file(ref, suffix='.ref')
@@ -528,7 +478,6 @@ class Skool2HtmlTest(SkoolKitTestCase):
             'JavaScriptPath={}',
             '[Page:CustomPage]',
             'JavaScript={}',
-            'Path=page.html',
             'PageContent=<b>Hello</b>'
         )).format(global_js_file, js_path, local_js_file)
         reffile = self.write_text_file(ref, suffix='.ref')
@@ -671,9 +620,7 @@ class Skool2HtmlTest(SkoolKitTestCase):
     def test_option_P(self):
         ref = '\n'.join((
             '[Page:Page1]',
-            'Path=page1.html',
-            '[Page:Page2]',
-            'Path=page2.html'
+            '[Page:Page2]'
         ))
         self.mock(skool2html, 'write_disassembly', mock_write_disassembly)
         reffile = self.write_text_file(ref, suffix='.ref')
@@ -688,11 +635,12 @@ class Skool2HtmlTest(SkoolKitTestCase):
 
     def test_option_w_m(self):
         exp_arg_list = [
-            ({'Name': 'MemoryMap', 'PageByteColumns': '1'},),
-            ({'EntryTypes': 'c', 'Name': 'RoutinesMap'},),
-            ({'EntryTypes': 'bw', 'Name': 'DataMap', 'PageByteColumns': '1'},),
-            ({'EntryTypes': 't', 'Name': 'MessagesMap'},),
-            ({'Name': 'UnusedMap', 'EntryTypes': 'suz', 'PageByteColumns': '1'},)
+            ('MemoryMap',),
+            ('RoutinesMap',),
+            ('DataMap',),
+            ('MessagesMap',),
+            ('UnusedMap',),
+            ('GameStatusBuffer',)
         ]
         self._test_option_w('--write', 'm', 'write_map', exp_arg_list)
 
@@ -702,12 +650,6 @@ class Skool2HtmlTest(SkoolKitTestCase):
     def test_option_w_P(self):
         self._test_option_w('--write', 'P', 'write_page', [('CustomPage1',), ('CustomPage2',)])
 
-    def test_option_w_G(self):
-        self._test_option_w('-w', 'G', 'write_gbuffer')
-
-    def test_option_w_g(self):
-        self._test_option_w('--write', 'g', 'write_graphics')
-
     def test_option_w_B(self):
         self._test_option_w('-w', 'B', 'write_graphic_glitches')
 
@@ -727,10 +669,10 @@ class Skool2HtmlTest(SkoolKitTestCase):
         self._test_option_w('--write', 'p', 'write_pokes')
 
     def test_option_w_o_map(self):
-        self._test_option_w('-w', 'o', 'write_map', [({'Path': 'other.html', 'Title': 'Other code', 'AsmPath': 'other'},)])
+        self._test_option_w('-w', 'o', 'write_map', [('other-Index',)])
 
     def test_option_w_o_entries(self):
-        self._test_option_w('--write', 'o', 'write_entries', [('other', 'other.html', 'Other code')])
+        self._test_option_w('--write', 'o', 'write_entries', [('other', 'other/other.html')])
 
     def test_option_w_i(self):
         self._test_option_w('-w', 'i', 'write_index')
@@ -858,5 +800,24 @@ class Skool2HtmlTest(SkoolKitTestCase):
             self.assertEqual(error, '')
             self.assertTrue(html_writer.parser.mode.hexadecimal)
 
+    def test_option_R(self):
+        for option in ('-R', '--ref-file'):
+            output, error = self.run_skool2html(option, catch_exit=0)
+            self.assertEqual(error, '')
+            self.assertEqual(output[0], '[Colours]')
+            self.assertTrue('[Titles]' in output)
+
+    def test_option_r(self):
+        for option in ('-r', '--ref-sections'):
+            for prefix, exp_headers in (
+                ('Colours', ['Colours']),
+                ('Template:index_section', ['Template:index_section', 'Template:index_section_item']),
+                ('Template:index_section$', ['Template:index_section'])
+            ):
+                output, error = self.run_skool2html('{} {}'.format(option, prefix), catch_exit=0)
+                self.assertEqual(error, '')
+                headers = [line[1:-1] for line in output if line.startswith('[') and line.endswith(']')]
+                self.assertEqual(exp_headers, headers)
+
 if __name__ == '__main__':
     unittest.main()
