@@ -2,7 +2,7 @@
 import re
 import unittest
 
-from skoolkittest import PY3, SkoolKitTestCase
+from skoolkittest import SkoolKitTestCase
 from skoolkit import SkoolParsingError
 from skoolkit.skoolasm import AsmWriter
 from skoolkit.skoolparser import SkoolParser, CASE_LOWER, CASE_UPPER, BASE_10, BASE_16
@@ -328,7 +328,10 @@ TEST_DECIMAL_ASM_UPPER = r"""
 ERROR_PREFIX = 'Error while parsing #{0} macro'
 
 def get_chr(code):
-    return chr(code) if PY3 else unichr(code).encode('utf-8')
+    try:
+        return unichr(code).encode('utf-8')
+    except NameError:
+        return chr(code)
 
 class AsmWriterTest(SkoolKitTestCase):
     def _get_writer(self, skool='', crlf=False, tab=False, case=None, base=None, instr_width=23, warn=False, asm_mode=1, fix_mode=0):
@@ -585,6 +588,7 @@ class AsmWriterTest(SkoolKitTestCase):
         writer = self._get_writer()
         self._test_unsupported_macro(writer, '#FONT55584,,,,1{1,2}')
         self._test_unsupported_macro(writer, '#FONT:[foo]0,,5')
+        self._test_unsupported_macro(writer, '#FONTaddr=32768,3,scale=4{x=1,width=26}(chars)')
 
     def test_macro_font_invalid(self):
         writer = self._get_writer()
@@ -671,9 +675,6 @@ class AsmWriterTest(SkoolKitTestCase):
         # No parameters (1)
         self.assert_error(writer, '#POKES', 'No parameters (expected 2)', prefix)
 
-        # No parameters (2)
-        self.assert_error(writer, '#POKESx', 'No parameters (expected 2)', prefix)
-
         # Not enough parameters (1)
         self.assert_error(writer, '#POKES0', "Not enough parameters (expected 2): '0'", prefix)
 
@@ -1001,6 +1002,7 @@ class AsmWriterTest(SkoolKitTestCase):
     def test_macro_scr(self):
         writer = self._get_writer()
         self._test_unsupported_macro(writer, '#SCR2(fname)')
+        self._test_unsupported_macro(writer, '#SCR2,w=8,h=8{x=1,width=62}(fname)')
 
     def test_macro_scr_invalid(self):
         writer = self._get_writer()
@@ -1034,6 +1036,7 @@ class AsmWriterTest(SkoolKitTestCase):
     def test_macro_udg(self):
         writer = self._get_writer()
         self._test_unsupported_macro(writer, '#UDG39144,6(safe_key)')
+        self._test_unsupported_macro(writer, '#UDG65432,scale=2,mask=2:65440{y=2,height=14}(key)')
 
     def test_macro_udg_invalid(self):
         writer = self._get_writer()
@@ -1042,7 +1045,9 @@ class AsmWriterTest(SkoolKitTestCase):
     def test_macro_udgarray(self):
         writer = self._get_writer()
         self._test_unsupported_macro(writer, '#UDGARRAY8,,,256;33008-33023(bubble)')
+        self._test_unsupported_macro(writer, '#UDGARRAY4,mask=2,step=256;33008-33023:33024-33039{x=1,width=126}(sprite)')
         self._test_unsupported_macro(writer, '#UDGARRAY*foo,2;bar(baz)')
+        self._test_unsupported_macro(writer, '#UDGARRAY*foo,delay=2;bar(baz)')
 
     def test_macro_udgarray_invalid(self):
         writer = self._get_writer()
